@@ -1,6 +1,6 @@
 package Tapper::Reports::Web::Controller::Tapper::Testruns;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::Reports::Web::Controller::Tapper::Testruns::VERSION = '5.0.12';
+$Tapper::Reports::Web::Controller::Tapper::Testruns::VERSION = '5.0.13';
 use parent 'Tapper::Reports::Web::Controller::Base';
 use Cwd;
 use Data::DPath 'dpath';
@@ -138,6 +138,32 @@ sub delete : Chained('id') PathPart('delete')
         $c->stash(force => 1);
 }
 
+sub pause : Chained('id') PathPart('pause')
+{
+        my ( $self, $c) = @_;
+
+        my $cmd = Tapper::Cmd::Testrun->new();
+        my $retval = $cmd->pause($c->stash->{testrun}->id);
+        if (not $retval) {
+                $c->response->body(qq(Can not pause testrun));
+                return;
+        }
+        $c->stash(testrun => $c->stash->{testrun}->id);
+}
+
+sub continue : Chained('id') PathPart('continue')
+{
+        my ( $self, $c) = @_;
+
+        my $cmd = Tapper::Cmd::Testrun->new();
+        my $retval = $cmd->continue($c->stash->{testrun}->id);
+        if (not $retval) {
+                $c->response->body(qq(Can not continue testrun));
+                return;
+        }
+        $c->stash(testrun => $c->stash->{testrun}->id);
+}
+
 sub rerun : Chained('id') PathPart('rerun') Args(0)
 {
         my ( $self, $c ) = @_;
@@ -151,6 +177,19 @@ sub rerun : Chained('id') PathPart('rerun') Args(0)
         $c->stash(testrun => $retval);
 }
 
+sub cancel : Chained('id') PathPart('cancel') Args(0)
+{
+        my ( $self, $c ) = @_;
+
+        my $cmd = Tapper::Cmd::Testrun->new();
+        my $retval = $cmd->cancel($c->stash->{testrun}->id, "Cancelled in Web GUI");
+        if ($retval) {
+                $c->response->body(qq(Can not cancel testrun: $retval));
+                return;
+        }
+        $c->stash(testrun => $c->stash->{testrun}->id);
+}
+
 sub preconditions : Chained('id') PathPart('preconditions') CaptureArgs(0)
 {
         my ( $self, $c ) = @_;
@@ -791,7 +830,7 @@ Tapper Team <tapper-ops@amazon.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2016 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2017 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
